@@ -1,7 +1,7 @@
 /******************************************************************************
  *                                                                            *
  *           GLISSANDO - GLauber Initial State Simulation AND mOre...         *
- *                           ver. 1.7                                         *
+ *                           ver. 1.61                                        *
  *                                                                            *
  * Authors: Wojciech Broniowski (Wojciech.Broniowski@ifj.edu.pl)              *
  *          Maciej Rybczynski   (Maciej.Rybczynski@pu.kielce.pl)              *
@@ -23,7 +23,7 @@
 
 //! the units for all dimentionful quantities are fm
 
-float ver=1.7; //! version of the code
+float ver=1.61; //! version of the code
 
 #include <math.h>
 #include <time.h>
@@ -485,7 +485,7 @@ full_event = new TTree("full_event","full event");
 
 float CD2=CD*CD;
 d=sqrt(SNN/PI/10.);      //! the wounding distance, 10 converts to fm^2 from mb
-float d2=d*d;
+float d2=d*2;
 dbin=d;                  //! the binary collision distance (= the wounding distance)
 float dbin2=dbin*dbin;
 float mbin=SBIN/SNN;     //! ratio for the hot-spot model
